@@ -1,36 +1,27 @@
 package com.icl.saxon;
-import com.icl.saxon.om.*;
-import com.icl.saxon.tree.TreeBuilder;
-import com.icl.saxon.tinytree.TinyBuilder;
 import com.icl.saxon.expr.*;
-import com.icl.saxon.om.Axis;
-import com.icl.saxon.pattern.AnyNodeTest;
+import com.icl.saxon.om.*;
 import com.icl.saxon.output.*;
-import com.icl.saxon.trace.*;  // e.g.
-import com.icl.saxon.style.XSLStyleSheet;
-import com.icl.saxon.style.TerminationException;
+import com.icl.saxon.pattern.AnyNodeTest;
 import com.icl.saxon.sort.NodeOrderComparer;
+import com.icl.saxon.style.TerminationException;
+import com.icl.saxon.style.XSLStyleSheet;
+import com.icl.saxon.tinytree.TinyBuilder;
+import com.icl.saxon.trace.SaxonEventMulticaster;
+import com.icl.saxon.trace.TraceListener;
+import com.icl.saxon.tree.TreeBuilder;
+import org.w3c.dom.Node;
+import org.xml.sax.SAXParseException;
 
 import javax.xml.transform.*;
-import javax.xml.transform.stream.*;
-import javax.xml.transform.sax.*;
-import javax.xml.transform.dom.*;
+import javax.xml.transform.dom.DOMSource;
+import javax.xml.transform.sax.SAXSource;
+import javax.xml.transform.sax.TransformerHandler;
+import java.util.Enumeration;
+import java.util.Hashtable;
 import java.util.Properties;
 
 
-import org.xml.sax.*;
-import org.xml.sax.helpers.*;
-import org.xml.sax.ext.*;
-
-import org.w3c.dom.Node;
-import org.w3c.dom.Document;
-import org.w3c.dom.Element;
-
-import java.net.URL;
-import java.util.*;
-import java.io.*;
-
-
 /**
   * <B>Controller</B> processes an XML file, calling registered node handlers
   * when appropriate to process its elements, character content, and attributes. <P>
@@ -45,28 +36,25 @@ import java.io.*;
   * therefore it acts as a NodeOrderComparer.
   * @author Michael H. Kay (mhkay@iclway.co.uk)
   */
-  
+
 public class Controller extends Transformer implements NodeOrderComparer {
 
     // Policies for handling recoverable errors
 
-    public final static int RECOVER_SILENTLY = 0;
-    public final static int RECOVER_WITH_WARNINGS = 1;
-    public final static int DO_NOT_RECOVER = 2;
+    public static final int RECOVER_SILENTLY = 0;
+    public static final int RECOVER_WITH_WARNINGS = 1;
+    public static final int DO_NOT_RECOVER = 2;
 
     private TransformerFactoryImpl factory;
     private Bindery bindery;                // holds values of global and local variables
-    private ContentHandler inputContentHandler = null;
-    private ContentHandler outputContentHandler = null;
     private NamePool namePool;
     private DecimalFormatManager decimalFormatManager;
     private Emitter messageEmitter;
-    //private LexicalHandler lexicalHandler = null;
     private RuleManager ruleManager;
     private Properties outputProperties;
     private Outputter currentOutputter;
     private ParameterSet parameters;
-    private PreparedStyleSheet preparedStyleSheet;    
+    private PreparedStyleSheet preparedStyleSheet;
     private TraceListener traceListener; // e.g.
     private boolean tracingIsSuspended = false;
     private URIResolver standardURIResolver;
@@ -74,15 +62,13 @@ public class Controller extends Transformer implements NodeOrderComparer {
     private ErrorListener errorListener;
     private XSLStyleSheet styleSheetElement;
     private int recoveryPolicy = RECOVER_WITH_WARNINGS;
-    private boolean outputterIsInitialized = false;
     private int treeModel = Builder.TINY_TREE;
     private boolean disableStripping = false;
-    
+
     private DocumentPool sourceDocumentPool;
     private Hashtable userDataTable;
     private boolean lineNumbering;
     private boolean preview;
-    private TransformerException transformFailure = null;
     private String diagnosticName = null;
 
     /**
@@ -90,25 +76,24 @@ public class Controller extends Transformer implements NodeOrderComparer {
     * that use the RuleManager to set up Java handlers for nodes, without using
     * a stylesheet
     */
-    
+
     public Controller() {
         this(new TransformerFactoryImpl());
         bindery = new Bindery();
     }
-    
+
     /**
     * Create a Controller and initialise variables. Constructor is protected,
     * the Controller should be created using newTransformer() in the PreparedStyleSheet
-    * class. 
+    * class.
     */
 
     protected Controller(TransformerFactoryImpl factory) {
-        this.factory = factory;    	
+        this.factory = factory;
 		namePool = NamePool.getDefaultNamePool();
-        //bindery = new Bindery();
         standardURIResolver = new StandardURIResolver(factory);
         userURIResolver = factory.getURIResolver();
-        
+
         errorListener = factory.getErrorListener();
         if (errorListener instanceof StandardErrorListener) {
             ((StandardErrorListener)errorListener).setRecoveryPolicy(
@@ -116,8 +101,8 @@ public class Controller extends Transformer implements NodeOrderComparer {
                               .intValue());
         }
         sourceDocumentPool = new DocumentPool();
-        userDataTable = new Hashtable();        
-        
+        userDataTable = new Hashtable();
+
         TraceListener tracer = (TraceListener)factory.getAttribute(FeatureKeys.TRACE_LISTENER);
         if (tracer!=null) {
             addTraceListener(tracer);
@@ -134,7 +119,64 @@ public class Controller extends Transformer implements NodeOrderComparer {
         }
 
     }
-    
+
+    /**
+     * <p>Reset this <code>Transformer</code> to its original configuration.</p>
+     * <p/>
+     * <p><code>Transformer</code> is reset to the same state as when it was created with
+     * {@link javax.xml.transform.TransformerFactory#newTransformer()},
+     * {@link javax.xml.transform.TransformerFactory#newTransformer(javax.xml.transform.Source source)} or
+     * {@link javax.xml.transform.Templates#newTransformer()}.
+     * <code>reset()</code> is designed to allow the reuse of existing <code>Transformer</code>s
+     * thus saving resources associated with the creation of new <code>Transformer</code>s.</p>
+     * <p/>
+     * <p>The reset <code>Transformer</code> is not guaranteed to have the same {@link javax.xml.transform.URIResolver}
+     * or {@link javax.xml.transform.ErrorListener} <code>Object</code>s, e.g. {@link Object#equals(Object obj)}.
+     * It is guaranteed to have a functionally equal <code>URIResolver</code>
+     * and <code>ErrorListener</code>.</p>
+     *
+     * <p>NOTE: the Saxon implementation of this method does not clear the document pool. This is because the
+     * reason for resetting an existing Transformer rather than creating a new one is to reuse resources, and
+     * the document pool is the most important resource held by the Transformer. If there is a requirement to
+     * clear the document pool, then it is possible either (a) to call the {@link #clearDocumentPool()} method,
+     * or (b) to create a new Transformer.
+     *
+     * @since 1.5
+     */
+    public void reset() {
+        clearParameters();
+        namePool = NamePool.getDefaultNamePool();
+        standardURIResolver = new StandardURIResolver(factory);
+        userURIResolver = factory.getURIResolver();
+        currentOutputter = null;
+        messageEmitter = null;
+        outputProperties = null;
+
+        errorListener = factory.getErrorListener();
+        if (errorListener instanceof StandardErrorListener) {
+            ((StandardErrorListener)errorListener).setRecoveryPolicy(
+                            ((Integer)factory.getAttribute(FeatureKeys.RECOVERY_POLICY))
+                              .intValue());
+        }
+        userDataTable = new Hashtable();
+
+        TraceListener tracer = (TraceListener)factory.getAttribute(FeatureKeys.TRACE_LISTENER);
+        if (tracer!=null) {
+            addTraceListener(tracer);
+        }
+
+        Boolean num = (Boolean)factory.getAttribute(FeatureKeys.LINE_NUMBERING);
+        if (num!=null && num.booleanValue()) {
+            setLineNumbering(true);
+        }
+
+        Integer model = (Integer)factory.getAttribute(FeatureKeys.TREE_MODEL);
+        if (model!=null) {
+            setTreeModel(model.intValue());
+        }
+
+    }
+
     public TransformerFactoryImpl getTransformerFactory() {
         return factory;
     }
@@ -171,7 +213,7 @@ public class Controller extends Transformer implements NodeOrderComparer {
     * any number of times, typically with different node handlers for each pass. The NodeInfo
     * will typically be the root of a tree built using com.icl.saxon.om.Builder.<p>
     */
-    
+
     public void run(NodeInfo node) throws TransformerException
     {
         Context initialContext = makeContext(node);
@@ -185,59 +227,59 @@ public class Controller extends Transformer implements NodeOrderComparer {
     /**
     * ApplyTemplates to process selected nodes using the handlers registered for a particular
     * mode.<br>
-    * @param select A node-set expression (or more accurately a node-list) 
+    * @param select A node-set expression (or more accurately a node-list)
     * that determines which nodes are selected.
-    * Note: if the nodes are to be sorted, the select Expression will take care of this. 
+    * Note: if the nodes are to be sorted, the select Expression will take care of this.
     * @param mode Identifies the processing mode. It should match the mode defined when the
     * element handler was registered using setHandler with a mode parameter. Set this parameter to
     * null to invoke the default mode.
     * @param parameters A ParameterSet containing the parameters to the handler/template being invoked.
-    * Specify null if there are no parameters. 
+    * Specify null if there are no parameters.
     */
 
     public void applyTemplates(Context c, Expression select, Mode mode, ParameterSet parameters)
             throws TransformerException
     {
         // Get an enumerator to iterate through the selected nodes
-        NodeEnumeration enum;
+        NodeEnumeration enm;
         if (select==null) {
-            enum = c.getCurrentNodeInfo().getEnumeration(Axis.CHILD, AnyNodeTest.getInstance());            
+            enm = c.getCurrentNodeInfo().getEnumeration(Axis.CHILD, AnyNodeTest.getInstance());
         } else {
-            enum = select.enumerate(c, false);
+            enm = select.enumerate(c, false);
         }
-            
+
         // if the enumerator can't calculate last() position, we wrap it in one that can.
 
-        if (!(enum instanceof LastPositionFinder)) {
-            enum = new LookaheadEnumerator(enum);
-        }            
+        if (!(enm instanceof LastPositionFinder)) {
+            enm = new LookaheadEnumerator(enm);
+        }
 
         int position = 1;
-        Context context = c.newContext();            
-        context.setLastPositionFinder((LastPositionFinder)enum);
+        Context context = c.newContext();
+        context.setLastPositionFinder((LastPositionFinder)enm);
         context.setMode(mode);
-        while(enum.hasMoreElements()) {
-            NodeInfo node = enum.nextElement();
+        while(enm.hasMoreElements()) {
+            NodeInfo node = enm.nextElement();
             //if (node==null) {
-            //    System.err.println("Got null node from " + enum.getClass());
+            //    System.err.println("Got null node from " + enm.getClass());
             //    node.getDisplayName();  // break it now
             //}
-            
+
             context.setCurrentNode(node);
             context.setContextNode(node);
             context.setPosition(position++);
-            
+
             // find the node handler for this node
-    
+
             NodeHandler eh = ruleManager.getHandler(node, mode, context);
-                
+
             if (eh==null) {             // Use the default action for the node
-                                        // No need to open a new stack frame!    
+                                        // No need to open a new stack frame!
                 defaultAction(node, context);
-                
+
             } else {
                 if (eh.needsStackFrame()) {
-                    bindery.openStackFrame(parameters);           
+                    bindery.openStackFrame(parameters);
                     if (isTracing()) { // e.g.
                 	    traceListener.enterSource(eh, context);
                  	    eh.start(node, context);
@@ -254,16 +296,16 @@ public class Controller extends Transformer implements NodeOrderComparer {
                 	} else {
                  	    eh.start(node, context);
                 	}
-                }                    
+                }
             }
-            
+
         }
     };
 
     /**
     * Perform the built-in template action for a given node
     */
-    
+
     private void defaultAction(NodeInfo node, Context context) throws TransformerException {
         switch(node.getNodeType()) {
             case NodeInfo.ROOT:
@@ -281,16 +323,16 @@ public class Controller extends Transformer implements NodeOrderComparer {
 	            return;
         }
     }
-	                            
+
     /**
     * Apply a template imported from the stylesheet containing the current template
     */
 
-    public void applyImports(Context c, Mode mode, int min, int max, ParameterSet params) 
+    public void applyImports(Context c, Mode mode, int min, int max, ParameterSet params)
     throws TransformerException {
         NodeInfo node = c.getCurrentNodeInfo();
         NodeHandler nh = ruleManager.getHandler(node, mode, min, max, c);
-        
+
 		if (nh==null) {             // use the default action for the node
             defaultAction(node, c);
         } else {
@@ -308,7 +350,7 @@ public class Controller extends Transformer implements NodeOrderComparer {
     * the second node comes first in document order; 0 if the two parameters
     * identify the same node
     */
-    
+
     public int compare(NodeInfo n1, NodeInfo n2) {
         if (sourceDocumentPool.getNumberOfDocuments() == 1) {
             return n1.compareOrder(n2);
@@ -316,11 +358,11 @@ public class Controller extends Transformer implements NodeOrderComparer {
         int doc1 = sourceDocumentPool.getDocumentNumber(n1.getDocumentRoot());
         int doc2 = sourceDocumentPool.getDocumentNumber(n2.getDocumentRoot());
         if (doc1==doc2) {
-            return n1.compareOrder(n2);                     
+            return n1.compareOrder(n2);
         } else {
             return (doc1 - doc2);
         }
-    }            
+    }
 
 
     ////////////////////////////////////////////////////////////////////////////////
@@ -328,11 +370,11 @@ public class Controller extends Transformer implements NodeOrderComparer {
     ////////////////////////////////////////////////////////////////////////////////
 
     /**
-    * Set the output properties for the transformation.  These 
-    * properties will override properties set in the templates 
+    * Set the output properties for the transformation.  These
+    * properties will override properties set in the templates
     * with xsl:output.
     */
-    
+
     public void setOutputProperties(Properties properties) {
         Enumeration keys = properties.keys();
         while(keys.hasMoreElements()) {
@@ -344,7 +386,7 @@ public class Controller extends Transformer implements NodeOrderComparer {
     /**
     * Get the output properties for the transformation.
     */
-    
+
     public Properties getOutputProperties() {
         if (outputProperties == null) {
             if (preparedStyleSheet==null) {
@@ -353,9 +395,9 @@ public class Controller extends Transformer implements NodeOrderComparer {
                 outputProperties = preparedStyleSheet.getOutputProperties();
             }
         }
-        
+
         // Make a copy, so that modifications to the returned properties have no effect
-        
+
         Properties newProps = new Properties();
         Enumeration keys = outputProperties.keys();
         while(keys.hasMoreElements()) {
@@ -395,26 +437,26 @@ public class Controller extends Transformer implements NodeOrderComparer {
     * Set a new output destination, supplying the output format details. <BR>
     * This affects all further output until resetOutputDestination() is called. Note that
     * it is the caller's responsibility to close the Writer after use.
-    * @param outputProperties Details of the new output format
+    * @param props Details of the new output format
     * @param result Details of the new output destination
     */
 
-    public void changeOutputDestination(Properties props, Result result) 
+    public void changeOutputDestination(Properties props, Result result)
     throws TransformerException {
         GeneralOutputter out = new GeneralOutputter(namePool);
         out.setOutputDestination(props, result);
         currentOutputter = out;
-    }        
+    }
 
     /**
     * Set a simple StringBuffer output destination. Used during calls to
     * xsl:attribute, xsl:comment, xsl:processing-instruction
     */
-    
+
     public void changeToTextOutputDestination(StringBuffer buffer) {
         StringOutputter out = new StringOutputter(buffer);
         out.setErrorListener(errorListener);
-        currentOutputter = out;        
+        currentOutputter = out;
     }
 
     /**
@@ -434,7 +476,7 @@ public class Controller extends Transformer implements NodeOrderComparer {
         //System.err.println("resetOutputDestination");
         if (currentOutputter==null) {
             throw new TransformerException("No outputter has been allocated");
-        }   
+        }
         currentOutputter.close();
         currentOutputter = outputter;
     }
@@ -448,7 +490,7 @@ public class Controller extends Transformer implements NodeOrderComparer {
 
     public Emitter makeMessageEmitter() throws TransformerException {
         String emitterClass = (String)factory.getAttribute(FeatureKeys.MESSAGE_EMITTER_CLASS);
-        
+
         Object emitter = Loader.getInstance(emitterClass);
         if (!(emitter instanceof Emitter)) {
             throw new TransformerException(emitterClass + " is not an Emitter");
@@ -495,15 +537,15 @@ public class Controller extends Transformer implements NodeOrderComparer {
 	/**
 	* Set the error listener
 	*/
-	
+
 	public void setErrorListener(ErrorListener listener) {
 		errorListener = listener;
 	}
-	
+
 	/**
 	* Get the error listener
 	*/
-	
+
 	public ErrorListener getErrorListener() {
 		return errorListener;
 	}
@@ -545,13 +587,13 @@ public class Controller extends Transformer implements NodeOrderComparer {
     public DocumentPool getDocumentPool() {
         return sourceDocumentPool;
     }
-    
+
     /**
     * Clear the document pool. This is sometimes useful when using the same Transformer
     * for a sequence of transformations, but it isn't done automatically, because when
     * the transformations use common look-up documents, the caching is beneficial.
     */
-    
+
     public void clearDocumentPool() {
         sourceDocumentPool = new DocumentPool();
     }
@@ -625,15 +667,15 @@ public class Controller extends Transformer implements NodeOrderComparer {
 	/**
 	* Set the name pool to be used
 	*/
-	
+
 	public void setNamePool(NamePool pool) {
 		namePool = pool;
 	}
-	
+
 	/**
 	* Get the name pool in use
 	*/
-	
+
 	public NamePool getNamePool() {
 		return namePool;
 	}
@@ -657,15 +699,15 @@ public class Controller extends Transformer implements NodeOrderComparer {
     /**
     * Disable whitespace stripping
     */
-    
+
     public void disableWhitespaceStripping(boolean disable) {
         disableStripping = disable;
     }
-    
+
     /**
     * Determine if whitespace stripping is disabled
     */
-    
+
     public boolean isWhitespaceStrippingDisabled() {
         return disableStripping;
     }
@@ -681,7 +723,7 @@ public class Controller extends Transformer implements NodeOrderComparer {
         } else {
             b = new TreeBuilder();
         }
-        Boolean timing = (Boolean)factory.getAttribute(FeatureKeys.TIMING);        
+        Boolean timing = (Boolean)factory.getAttribute(FeatureKeys.TIMING);
         b.setTiming((timing==null ? false : timing.booleanValue()));
         b.setNamePool(namePool);
         b.setLineNumbering(lineNumbering);
@@ -695,12 +737,12 @@ public class Controller extends Transformer implements NodeOrderComparer {
         }
 		stripper.setController(this);
 		b.setStripper(stripper);
-		
+
         return b;
     }
 
     //////////////////////////////////////////////////////////////////////
-    // Methods for handling decimal-formats 
+    // Methods for handling decimal-formats
     //////////////////////////////////////////////////////////////////////
 
 
@@ -739,7 +781,7 @@ public class Controller extends Transformer implements NodeOrderComparer {
     public final boolean isTracing() { // e.g.
         return traceListener != null && !tracingIsSuspended;
     }
-    
+
     public void pauseTracing(boolean pause) {
         tracingIsSuspended = pause;
     }
@@ -755,23 +797,15 @@ public class Controller extends Transformer implements NodeOrderComparer {
         //setOutputProperties(sheet.getOutputProperties());
         // above line deleted for bug 490964 - may have side-effects
     }
-    
+
     /**
     * Does this transformation use preview mode?
     */
-    
+
     protected boolean usesPreviewMode() {
         return preview;
     }
 
-    /**
-    * Get the top element of the stylesheet document
-    */
-
-    private XSLStyleSheet getXSLStyleSheet() {
-         return styleSheetElement;
-    }
-    
     /**
     * Internal method to create and initialize a controller
     */
@@ -800,7 +834,7 @@ public class Controller extends Transformer implements NodeOrderComparer {
     * Must be called before the invocation of the render method.
     * @param    trace the trace listener.
     */
-    
+
     public void addTraceListener(TraceListener trace) { // e.g.
         traceListener = SaxonEventMulticaster.add(traceListener, trace);
     }
@@ -810,7 +844,7 @@ public class Controller extends Transformer implements NodeOrderComparer {
     * of the render method will not send trace events to the listener.
     * @param    trace the trace listener.
     */
-    
+
     public void removeTraceListener(TraceListener trace) { // e.g.
         traceListener = SaxonEventMulticaster.remove(traceListener, trace);
     }
@@ -821,27 +855,29 @@ public class Controller extends Transformer implements NodeOrderComparer {
 
     /**
     * Get the named user data property for the node
-    * @param the name of the user data property to return
+    * @param name the name of the user data property to return
     * @return The value of the named user data property.
-    * Returns null if no property of that name has been set using setUserData() 
+    * Returns null if no property of that name has been set using setUserData()
     * for this NodeInfo object.
     */
 
     public Object getUserData(NodeInfo node, String name)  {
-        String key = name + " " + node.generateId();
+        String key = name + ' ' + getDocumentPool().getDocumentNumber(node.getDocumentRoot()) + node.generateId();
+// ABOVE LINE PATCHED 2004-10-08
         return userDataTable.get(key);
     }
-    
+
     /**
     * Set a user data property for a node.
     * @param name The name of the user data property to be set. Any existing user data property
     * of the same name will be overwritten.
-    * @param userData an object to be saved with this element, which can be
+    * @param data an object to be saved with this element, which can be
     * retrieved later using getUserData().
     */
-    
+
     public void setUserData(NodeInfo node, String name, Object data)  {
-        String key = name + " " + node.generateId();
+        String key = name + ' ' + getDocumentPool().getDocumentNumber(node.getDocumentRoot()) + node.generateId();
+// ABOVE LINE PATCHED 2004-10-08
         if (data==null) {
             userDataTable.remove(key);
         } else {
@@ -862,7 +898,7 @@ public class Controller extends Transformer implements NodeOrderComparer {
     * the method throws a TerminationException (a subclass of TransformerException)
     * if the transformation was terminated using xsl:message terminate="yes".
     */
-    
+
     public void transform(Source source, Result result) throws TransformerException {
         if (preparedStyleSheet==null) {
             throw new TransformerException("Stylesheet has not been prepared");
@@ -870,7 +906,7 @@ public class Controller extends Transformer implements NodeOrderComparer {
 
         PreviewManager pm = styleSheetElement.getPreviewManager();
         preview = (pm!=null);
-        
+
         String path = "/";
 
         try {
@@ -884,16 +920,16 @@ public class Controller extends Transformer implements NodeOrderComparer {
             }
             if (source instanceof DOMSource) {
                 DOMSource ds = (DOMSource)source;
-                
+
                 if (preview) {
                     throw new TransformerException("Preview mode requires serial input");
                 }
                 if (disableStripping || !styleSheetElement.stripsWhitespace()) {
-                    
-                    if ( ds.getNode() instanceof NodeInfo ) {               
+
+                    if ( ds.getNode() instanceof NodeInfo ) {
 
                         // bypass the tree building stage, and work on the tree as supplied
-                
+
                         transformDocument((NodeInfo)ds.getNode(), result);
                         return;
                     }
@@ -901,11 +937,11 @@ public class Controller extends Transformer implements NodeOrderComparer {
                 path = getPathToNode(ds.getNode());
                 // System.err.println("path = " + path);
             }
-                 
+
         	SAXSource in = factory.getSAXSource(source, false);
-        	
-            // System.err.println("transform " + diagnosticName);                
-            
+
+            // System.err.println("transform " + diagnosticName);
+
             if (preview) {
                 // run the build in preview mode
                 initializeController();
@@ -914,20 +950,20 @@ public class Controller extends Transformer implements NodeOrderComparer {
                 // in preview mode we don't try to use xsl:output properties
                 // for the principal output file, because in XSLT 1.1 they can
                 // be attribute value templates, and we can't evaluate these yet.
-                
+
                 if (outputProperties==null) {
                     outputProperties = new Properties();
                 }
                 changeOutputDestination(outputProperties, result);
-            
+
                 Builder sourceBuilder = makeBuilder();
                 sourceBuilder.setController(this);
                 sourceBuilder.setPreviewManager(pm);
-                sourceBuilder.setNamePool(namePool);       
+                sourceBuilder.setNamePool(namePool);
                 DocumentInfo doc = sourceBuilder.build(in);
                 sourceDocumentPool.add(doc, null);
                 sourceBuilder = null;   // give the garbage collector a chance
-                
+
                 transformDocument(doc, result);
                 resetOutputDestination(null);
 
@@ -937,14 +973,14 @@ public class Controller extends Transformer implements NodeOrderComparer {
                 // ((com.icl.saxon.tinytree.TinyDocumentImpl)doc).diagnosticDump();
                 sourceDocumentPool.add(doc, null);
                 sourceBuilder = null;   // give the garbage collector a chance
-                
+
                 NodeInfo startNode = doc;
                 if (!path.equals("/")) {
                     Expression exp = Expression.make(path, new StandaloneContext(namePool));
                     Context c = makeContext(doc);
-                    NodeEnumeration enum = exp.enumerate(c, false);
-                    if (enum.hasMoreElements()) {
-                        startNode = enum.nextElement();
+                    NodeEnumeration enm = exp.enumerate(c, false);
+                    if (enm.hasMoreElements()) {
+                        startNode = enm.nextElement();
                     } else {
                         throw new TransformerException("Problem finding the start node after converting DOM to Saxon tree");
                     }
@@ -963,13 +999,13 @@ public class Controller extends Transformer implements NodeOrderComparer {
                 errorListener.fatalError(err);
             }
             throw err;
-        } 
+        }
     }
 
     /**
     * Get an XPath expression referencing a node in a DOM
     */
-    
+
     private String getPathToNode(Node startNode) throws TransformerException {
         short nodeType = startNode.getNodeType();
         String path;
@@ -978,7 +1014,7 @@ public class Controller extends Transformer implements NodeOrderComparer {
         } else if ( nodeType == Node.ELEMENT_NODE ) {
             path = "";
             Node curr = startNode;
-            while ( nodeType == Node.ELEMENT_NODE ) {                    
+            while ( nodeType == Node.ELEMENT_NODE ) {
                 int count = 1;
                 Node prior = curr.getPreviousSibling();
                 while (prior != null) {
@@ -993,17 +1029,17 @@ public class Controller extends Transformer implements NodeOrderComparer {
                     prior = prior.getPreviousSibling();
                 }
                 if (!path.equals("")) {
-                    path = "/" + path;
+                    path = '/' + path;
                 }
-                path = "*[" + count + "]" + path;
-                
+                path = "*[" + count + ']' + path;
+
                 curr = curr.getParentNode();
                 if (curr==null) {
                     throw new TransformerException("Supplied element is not within a Document");
                 }
                 nodeType = curr.getNodeType();
                 if (nodeType == Node.DOCUMENT_NODE) {
-                    path = "/" + path;
+                    path = '/' + path;
                 } else if (nodeType == Node.CDATA_SECTION_NODE ||
                             nodeType == Node.ENTITY_REFERENCE_NODE) {
                     throw new TransformerException(
@@ -1013,21 +1049,21 @@ public class Controller extends Transformer implements NodeOrderComparer {
         } else {
             throw new TransformerException("Start node must be either the root or an element");
         }
-        return path;                                            
+        return path;
     }
 
     /**
     * Render a source XML document supplied as a tree. <br>
     * A new output destination should be created for each source document,
     * by using setOutputDetails(). <br>
-    * @param startNode A Node that identifies the source document to be transformed and the 
+    * @param startNode A Node that identifies the source document to be transformed and the
     * node where the transformation should start
     * @param result The output destination
     */
 
-    public void transformDocument(NodeInfo startNode, Result result) 
+    public void transformDocument(NodeInfo startNode, Result result)
     throws TransformerException {
-        
+
         DocumentInfo sourceDoc;
         if (startNode instanceof DocumentInfo) {
             sourceDoc = (DocumentInfo)startNode;
@@ -1035,8 +1071,6 @@ public class Controller extends Transformer implements NodeOrderComparer {
             sourceDoc = startNode.getDocumentRoot();
         }
 
-        transformFailure = null;
-
         if (styleSheetElement==null) {
             throw new TransformerException("Stylesheet has not been prepared");
         }
@@ -1058,28 +1092,28 @@ public class Controller extends Transformer implements NodeOrderComparer {
             styleSheetElement.updateOutputProperties(xslOutputProps, context);
             // overlay the output properties defined via the API
             if (outputProperties!=null) {
-                Enumeration enum = outputProperties.propertyNames();
-                while (enum.hasMoreElements()) {
-                    String p = (String)enum.nextElement();
+                Enumeration enm = outputProperties.propertyNames();
+                while (enm.hasMoreElements()) {
+                    String p = (String)enm.nextElement();
                     String v = outputProperties.getProperty(p);
                     xslOutputProps.put(p, v);
                 }
             }
-            
+
             // deal with stylesheet chaining
             String nextInChain = xslOutputProps.getProperty(SaxonOutputKeys.NEXT_IN_CHAIN);
             if (nextInChain != null) {
                 String baseURI = xslOutputProps.getProperty(SaxonOutputKeys.NEXT_IN_CHAIN_BASE_URI);
-                result = prepareNextStylesheet(nextInChain, baseURI, result); 
-            } 
-                
+                result = prepareNextStylesheet(nextInChain, baseURI, result);
+            }
+
             changeOutputDestination(xslOutputProps, result);
         }
 
-        // process the stylesheet document 
+        // process the stylesheet document
         // (The main function of this phase is to evaluate global variables)
 
-        styleSheetElement.process(context);            
+        styleSheetElement.process(context);
 
         // Process the source document using the handlers that have been set up
 
@@ -1099,12 +1133,12 @@ public class Controller extends Transformer implements NodeOrderComparer {
     * Prepare another stylesheet to handle the output of this one
     */
 
-    private Result prepareNextStylesheet(String href, String baseURI, Result result) 
+    private Result prepareNextStylesheet(String href, String baseURI, Result result)
     throws TransformerException {
 
         //TODO: should cache the results, we are recompiling the referenced
         //stylesheet each time it's used
-        
+
         //TODO: combine with similar method in XSLGeneralOutput
 
         Source source = getURIResolver().resolve(href, baseURI);
@@ -1118,7 +1152,7 @@ public class Controller extends Transformer implements NodeOrderComparer {
         emitter.setSystemId(saxSource.getSystemId());   // pragmatic choice of system ID
         emitter.setRequireWellFormed(false);
         nextTransformer.setResult(result);
-        
+
         return emitter;
     }
 
@@ -1128,11 +1162,11 @@ public class Controller extends Transformer implements NodeOrderComparer {
 
     /**
     * Set a parameter for the transformation.
-    * @param name The name of the parameter in {uri}local format  
-    * @value The value object.  This can be any valid Java object 
+    * @param expandedName The name of the parameter in {uri}local format
+    * @param value The value object.  This can be any valid Java object
     * it follows the same conversion rules as a value returned from a Saxon extension function.
     */
-    
+
     public void setParameter(String expandedName, Object value) {
 
         if (parameters == null) {
@@ -1145,15 +1179,15 @@ public class Controller extends Transformer implements NodeOrderComparer {
         } catch (TransformerException err) {
             result = new StringValue(value.toString());
         }
-        int fingerprint = getFingerprintForExpandedName(expandedName);        
+        int fingerprint = getFingerprintForExpandedName(expandedName);
         parameters.put(fingerprint, result);
-       
+
     }
 
     /**
     * Set parameters supplied externally (typically, on the command line).
     * (non-TRAX method retained for backwards compatibility)
-    * @param params A ParameterSet containing the (name, value) pairs. 
+    * @param params A ParameterSet containing the (name, value) pairs.
     */
 
     public void setParams(ParameterSet params) {
@@ -1182,14 +1216,14 @@ public class Controller extends Transformer implements NodeOrderComparer {
             namespace = "";
             localName = expandedName;
         }
-            
+
         return namePool.allocate("", namespace, localName);
     }
 
     /**
-    * Reset the parameters to a null list.  
+    * Reset the parameters to a null list.
     */
-    
+
     public void clearParameters() {
         parameters = null;
     }
@@ -1203,36 +1237,36 @@ public class Controller extends Transformer implements NodeOrderComparer {
         int f = getFingerprintForExpandedName(expandedName);
         return parameters.get(f);
     }
-  
+
     /**
-    * Set an object that will be used to resolve URIs used in 
+    * Set an object that will be used to resolve URIs used in
     * document(), etc.
-    * @param resolver An object that implements the URIResolver interface, 
+    * @param resolver An object that implements the URIResolver interface,
     * or null.
     */
-    
+
     public void setURIResolver(URIResolver resolver) {
         userURIResolver = resolver;
     }
-  
+
 }   // end of outer class Controller
 
 //
 // The contents of this file are subject to the Mozilla Public License Version 1.0 (the "License");
 // you may not use this file except in compliance with the License. You may obtain a copy of the
-// License at http://www.mozilla.org/MPL/ 
+// License at http://www.mozilla.org/MPL/
 //
 // Software distributed under the License is distributed on an "AS IS" basis,
 // WITHOUT WARRANTY OF ANY KIND, either express or implied.
-// See the License for the specific language governing rights and limitations under the License. 
+// See the License for the specific language governing rights and limitations under the License.
 //
-// The Original Code is: all this file. 
+// The Original Code is: all this file.
 //
 // The Initial Developer of the Original Code is
 // Michael Kay of International Computers Limited (mhkay@iclway.co.uk).
 //
-// Portions created by (your name) are Copyright (C) (your legal entity). All Rights Reserved. 
+// Portions created by (your name) are Copyright (C) (your legal entity). All Rights Reserved.
 //
-// Contributor(s): 
+// Contributor(s):
 // Portions marked "e.g." are from Edwin Glaser (edwin@pannenleiter.de)
 //
