@@ -1,32 +1,16 @@
 package com.icl.saxon;
-import com.icl.saxon.tree.TreeBuilder;
-import com.icl.saxon.tinytree.TinyBuilder;
+import com.icl.saxon.expr.StringValue;
 import com.icl.saxon.om.Builder;
-import com.icl.saxon.om.Navigator;
-import com.icl.saxon.om.DocumentInfo;
-import com.icl.saxon.om.Namespace;
 import com.icl.saxon.om.NamePool;
-import com.icl.saxon.expr.*;
-import com.icl.saxon.style.*;
-import com.icl.saxon.output.*;
-import com.icl.saxon.trace.*;
 import com.icl.saxon.style.TerminationException;
-
-import org.xml.sax.SAXException;
-import org.xml.sax.helpers.AttributesImpl;
-import org.xml.sax.*;
-
-import org.w3c.dom.Node;
-import org.w3c.dom.Document;
-
-import java.util.*;
-import java.io.*;
-import java.net.URL;
-import java.net.MalformedURLException;
+import com.icl.saxon.trace.TraceListener;
 
 import javax.xml.transform.*;
-import javax.xml.transform.sax.*;
-import javax.xml.transform.stream.*;
+import javax.xml.transform.sax.SAXSource;
+import javax.xml.transform.stream.StreamResult;
+import java.io.File;
+import java.util.Date;
+import java.util.Properties;
 
 /**
   * This <B>StyleSheet</B> class is the entry point to the Saxon XSLT Processor. This
@@ -38,15 +22,15 @@ import javax.xml.transform.stream.*;
   *
   * @author M.H.Kay (mhkay@iclway.co.uk)
   */
-  
+
 public class StyleSheet  {
 
 	protected TransformerFactoryImpl factory = new TransformerFactoryImpl();
-	
+
     protected NamePool namePool = NamePool.getDefaultNamePool();
     boolean showTime = false;
     int repeat = 1;
-        
+
     /**
     * Main program, can be used directly from the command line.
     * <p>The format is:</P>
@@ -55,7 +39,7 @@ public class StyleSheet  {
     * referenced from within the stylesheet.</p>
     * <p>This program applies the XSL style sheet in style-file to the source XML document in source-file.</p>
     */
-    
+
     public static void main (String args[])
         throws java.lang.Exception
     {
@@ -72,8 +56,8 @@ public class StyleSheet  {
     */
 
     protected void doMain(String args[], StyleSheet app, String name) {
-        
-        
+
+
         String sourceFileName = null;
         String styleFileName = null;
         File sourceFile = null;
@@ -85,7 +69,7 @@ public class StyleSheet  {
         String outputFileName = null;
         boolean useAssociatedStylesheet = false;
         boolean wholeDirectory = false;
-        
+
 				// Check the command-line arguments.
 
         try {
@@ -126,7 +110,7 @@ public class StyleSheet  {
                         useURLs = true;
                         i++;
                     }
-        
+
                     else if (args[i].equals("-t")) {
                         System.err.println(Version.getProductName());
                         System.err.println("Java version " + System.getProperty("java.version"));
@@ -148,7 +132,7 @@ public class StyleSheet  {
                         i++;
                         repeat = 9;
                     }
-        
+
                     else if (args[i].equals("-o")) {
                         i++;
                         if (args.length < i+2) badUsage(name, "No output file name");
@@ -197,7 +181,7 @@ public class StyleSheet  {
                         TraceListener traceListener = makeTraceListener(args[i++]);
                         factory.setAttribute(
                                 FeatureKeys.TRACE_LISTENER,
-                                traceListener);                        
+                                traceListener);
                         factory.setAttribute(
                                 FeatureKeys.LINE_NUMBERING,
                                 Boolean.TRUE);
@@ -207,50 +191,50 @@ public class StyleSheet  {
                         i++;
                         factory.setAttribute(
                                 FeatureKeys.RECOVERY_POLICY,
-                                new Integer(Controller.RECOVER_SILENTLY));              
+                                new Integer(Controller.RECOVER_SILENTLY));
                     }
                     else if (args[i].equals("-w1")) {
                         i++;
                         factory.setAttribute(
                                 FeatureKeys.RECOVERY_POLICY,
-                                new Integer(Controller.RECOVER_WITH_WARNINGS));      
+                                new Integer(Controller.RECOVER_WITH_WARNINGS));
                     }
                     else if (args[i].equals("-w2")) {
                         i++;
                         factory.setAttribute(
                                 FeatureKeys.RECOVERY_POLICY,
-                                new Integer(Controller.DO_NOT_RECOVER));      
+                                new Integer(Controller.DO_NOT_RECOVER));
                     }
-                    
+
                     else if (args[i].equals("-m")) {
                         i++;
                         if (args.length < i+2) badUsage(name, "No message Emitter class");
                         factory.setAttribute(
                                 FeatureKeys.MESSAGE_EMITTER_CLASS,
-                                args[i++]);                              
+                                args[i++]);
                     }
 
                     else if (args[i].equals("-noext")) {
                         i++;
                         factory.setAttribute(
                                 FeatureKeys.ALLOW_EXTERNAL_FUNCTIONS,
-                                new Boolean(false));                              
+                                new Boolean(false));
                     }
 
                     else badUsage(name, "Unknown option " + args[i]);
                 }
-            
+
                 else break;
             }
 
-            if (args.length < i+1 ) badUsage(name, "No source file name");        
+            if (args.length < i+1 ) badUsage(name, "No source file name");
             sourceFileName = args[i++];
 
             if (!useAssociatedStylesheet) {
-                if (args.length < i+1 ) badUsage(name, "No stylesheet file name");        
+                if (args.length < i+1 ) badUsage(name, "No stylesheet file name");
                 styleFileName = args[i++];
             }
-        
+
             for (int p=i; p<args.length; p++) {
                 String arg = args[p];
                 int eq = arg.indexOf("=");
@@ -303,14 +287,14 @@ public class StyleSheet  {
                     processFileAssoc(sourceInput, null, outputFile, params);
                 }
             } else {
-                
+
                 long startTime = (new Date()).getTime();
 
                 Source styleSource;
                 if (useURLs || styleFileName.startsWith("http:")
                                  || styleFileName.startsWith("file:")) {
                     styleSource = factory.getURIResolver().resolve(styleFileName, null);
-                    
+
                 } else {
                     File sheetFile = new File(styleFileName);
                     if (!sheetFile.exists()) {
@@ -319,7 +303,7 @@ public class StyleSheet  {
                     ExtendedInputSource eis = new ExtendedInputSource(sheetFile);
                     styleSource = new SAXSource(factory.getStyleParser(), eis);
                 }
-                    
+
                 if (styleSource==null) {
                     quit("URIResolver for stylesheet file must return a Source", 2);
                 }
@@ -331,21 +315,21 @@ public class StyleSheet  {
                     System.err.println("Preparation time: " + (endTime-startTime) + " milliseconds");
                     startTime = endTime;
                 }
-                
-                if (wholeDirectory) {        
+
+                if (wholeDirectory) {
                     processDirectory(sourceFile, sheet, outputFile, params);
                 } else {
                     processFile(sourceInput, sheet, outputFile, params);
                 }
             }
         } catch (TerminationException err) {
-            quit(err.getMessage(), 1);            
+            quit(err.getMessage(), 1);
         } catch (TransformerException err) {
             quit("Transformation failed: " + err.getMessage(), 2);
         } catch (Exception err2) {
             err2.printStackTrace();
         }
-        
+
 
         //System.exit(0);
     }
@@ -411,7 +395,7 @@ public class StyleSheet  {
         }
         return new File(directory, prefix+suffix);
     }
-            
+
 
     /**
     * Process a single source file using its associated stylesheet(s)
@@ -431,18 +415,18 @@ public class StyleSheet  {
         if (showTime) {
             System.err.println("Prepared associated stylesheet " + style.getSystemId());
         }
-		Transformer instance = sheet.newTransformer();			
+		Transformer instance = sheet.newTransformer();
         ((Controller)instance).setParams(params);
-        
+
         File outFile = outputFile;
-    
+
         if (outFile!=null && outFile.isDirectory()) {
             outFile = makeOutputFile(outFile, localName, sheet);
         }
 
-        StreamResult result = 
+        StreamResult result =
             (outFile==null ? new StreamResult(System.out) : new StreamResult(outFile));
-        
+
         try {
             instance.transform(sourceInput, result);
         } catch (TerminationException err) {
@@ -451,7 +435,7 @@ public class StyleSheet  {
             // The error message will already have been displayed; don't do it twice
             throw new TransformerException("Run-time errors were reported");
         }
-    
+
         if (showTime) {
             long endTime = (new Date()).getTime();
             System.err.println("Execution time: " + (endTime-startTime) + " milliseconds");
@@ -467,13 +451,13 @@ public class StyleSheet  {
         File sourceDir, Templates sheet, File outputDir, ParameterSet params)
         throws TransformerException
     {
-            
+
         String[] files = sourceDir.list();
         int failures = 0;
         for (int f=0; f<files.length; f++) {
             File file = new File(sourceDir, files[f]);
             String localName = file.getName();
-            try {                
+            try {
                 if (!file.isDirectory()) {
                     File outputFile = makeOutputFile(outputDir, localName, sheet);
                     ExtendedInputSource eis = new ExtendedInputSource(file);
@@ -483,7 +467,7 @@ public class StyleSheet  {
             } catch (TransformerException err) {
                 failures++;
                 System.err.println("While processing " + localName + ": " + err.getMessage() + "\n");
-            }                
+            }
         }
         if (failures>0) {
             throw new TransformerException(failures + " transformation" +
@@ -501,7 +485,7 @@ public class StyleSheet  {
 
         for (int r=0; r<repeat; r++) {      // repeat is for internal testing/timing
             if (showTime) {
-                System.err.println("Processing " + source.getSystemId());                
+                System.err.println("Processing " + source.getSystemId());
             }
             long startTime = (new Date()).getTime();
             Transformer instance = sheet.newTransformer();
@@ -540,9 +524,9 @@ public class StyleSheet  {
         System.err.println("  -o filename     Send output to named file or directory ");
         System.err.println("  -m classname    Use specified Emitter class for xsl:message output ");
         System.err.println("  -r classname    Use specified URIResolver class ");
-        System.err.println("  -t              Display version and timing information ");        
-        System.err.println("  -T              Set standard TraceListener");  
-        System.err.println("  -TL classname   Set a specific TraceListener");  
+        System.err.println("  -t              Display version and timing information ");
+        System.err.println("  -T              Set standard TraceListener");
+        System.err.println("  -TL classname   Set a specific TraceListener");
         System.err.println("  -u              Names are URLs not filenames ");
         System.err.println("  -w0             Recover silently from recoverable errors ");
         System.err.println("  -w1             Report recoverable errors and continue (default)");
@@ -553,7 +537,7 @@ public class StyleSheet  {
         System.exit(2);
     }
 
-    public static URIResolver makeURIResolver (String className) 
+    public static URIResolver makeURIResolver (String className)
     throws TransformerException
     {
         Object obj = Loader.getInstance(className);
@@ -563,13 +547,13 @@ public class StyleSheet  {
         throw new TransformerException("Class " + className + " is not a URIResolver");
     }
 
-    public static TraceListener makeTraceListener (String className) 
+    public static TraceListener makeTraceListener (String className)
     throws TransformerException
     {
         Object obj = Loader.getInstance(className);
         if (obj instanceof TraceListener) {
             return (TraceListener)obj;
-        }        
+        }
         throw new TransformerException("Class " + className + " is not a TraceListener");
     }
 
@@ -578,18 +562,18 @@ public class StyleSheet  {
 //
 // The contents of this file are subject to the Mozilla Public License Version 1.0 (the "License");
 // you may not use this file except in compliance with the License. You may obtain a copy of the
-// License at http://www.mozilla.org/MPL/ 
+// License at http://www.mozilla.org/MPL/
 //
 // Software distributed under the License is distributed on an "AS IS" basis,
 // WITHOUT WARRANTY OF ANY KIND, either express or implied.
-// See the License for the specific language governing rights and limitations under the License. 
+// See the License for the specific language governing rights and limitations under the License.
 //
-// The Original Code is: all this file. 
+// The Original Code is: all this file.
 //
 // The Initial Developer of the Original Code is
 // Michael Kay of International Computers Limited (mhkay@iclway.co.uk).
 //
-// Portions created by (your name) are Copyright (C) (your legal entity). All Rights Reserved. 
+// Portions created by (your name) are Copyright (C) (your legal entity). All Rights Reserved.
 //
-// Contributor(s): none. 
+// Contributor(s): none.
 //
