@@ -33,7 +33,7 @@ public class Extensions  {
     public static void resumeTracing(Context c) {
         c.getController().pauseTracing(false);
     }
-    
+
     /**
     * Convert a result tree fragment to a node-set. This simply marks a result
     * tree fragment as being available for general use.
@@ -46,21 +46,21 @@ public class Extensions  {
         if (frag instanceof NodeSetValue) {
             return (NodeSetValue)frag;
         } else {
-            TextFragmentValue v = 
+            TextFragmentValue v =
                 new TextFragmentValue(frag.asString(), "", c.getController());
             v.allowGeneralUse();
             return v;
-        }        
+        }
     }
 
     /**
     * Alternative spelling (allows "nodeset()")
     */
-    
+
     public static NodeSetValue nodeset(Context c, Value frag) throws XPathException {
         return nodeSet(c, frag);
     }
-    
+
     /**
     * Return the system identifier of the context node
     */
@@ -129,7 +129,7 @@ public class Extensions  {
             if (!e2.hasMoreElements()) {
                 return false;
             }
-            if (!e1.nextElement().isSameNode(e2.nextElement())) {
+            if (!e1.nextElement().isSameNodeInfo(e2.nextElement())) {
                 return false;
             }
         }
@@ -154,7 +154,7 @@ public class Extensions  {
     }
 
     /**
-    * Evaluate the expression supplied in the first argument as a string 
+    * Evaluate the expression supplied in the first argument as a string
     */
 
     public static Value evaluate (Context c, String expr) throws XPathException {
@@ -165,7 +165,7 @@ public class Extensions  {
     }
 
     /**
-    * Evaluate the stored expression supplied in the first argument 
+    * Evaluate the stored expression supplied in the first argument
     */
 
     public static Value eval (Context c, Expression expr) throws XPathException {
@@ -174,7 +174,7 @@ public class Extensions  {
 
     /**
     * Return an object representing a stored expression,
-    * from the string supplied in the first argument. 
+    * from the string supplied in the first argument.
     */
 
     public static Value expression (Context c, String expr) throws XPathException {
@@ -378,16 +378,16 @@ public class Extensions  {
     }
 
     /**
-    * Evaluate the transitive closure of a node-set expression 
+    * Evaluate the transitive closure of a node-set expression
     */
 
     public static NodeEnumeration closure (Context c,
-            NodeEnumeration enum, Expression expr) throws XPathException {
-                
+            NodeEnumeration enm, Expression expr) throws XPathException {
+
         NodeEnumeration result = EmptyEnumeration.getInstance();
         Controller controller = c.getController();
-        while(enum.hasMoreElements()) {
-            NodeInfo node = enum.nextElement();
+        while(enm.hasMoreElements()) {
+            NodeInfo node = enm.nextElement();
             Context c2 = c.newContext();
             c2.setContextNode(node);
             c2.setCurrentNode(node);
@@ -410,7 +410,7 @@ public class Extensions  {
 
     public static NodeEnumeration leading (Context context,
                          NodeEnumeration in, Expression exp) throws XPathException {
-        return new FilterEnumerator(in, exp, context.newContext(), true); 
+        return new FilterEnumerator(in, exp, context.newContext(), true);
     }
 
     /**
@@ -432,18 +432,18 @@ public class Extensions  {
             return new EmptyNodeSet();
         }
         Controller controller = context.getController();
-                
+
         Vector v = new Vector();
-        NodeEnumeration enum = ns1.enumerate();
-        while (enum.hasMoreElements()) {
-            NodeInfo node = enum.nextElement();
+        NodeEnumeration enm = ns1.enumerate();
+        while (enm.hasMoreElements()) {
+            NodeInfo node = enm.nextElement();
             if (controller.compare(node, test) < 0) {
                 v.addElement(node);
             } else {
                 break;
             }
         }
-        return new NodeSetExtent(v, controller);                  
+        return new NodeSetExtent(v, controller);
 
     }
 
@@ -461,20 +461,20 @@ public class Extensions  {
             return new EmptyNodeSet();
         }
         Controller controller = context.getController();
-            
+
         Vector v = new Vector();
-        NodeEnumeration enum = ns1.enumerate();
+        NodeEnumeration enm = ns1.enumerate();
         boolean pastLimit = false;
-        while (enum.hasMoreElements()) {
-            NodeInfo node = enum.nextElement();
+        while (enm.hasMoreElements()) {
+            NodeInfo node = enm.nextElement();
             if (pastLimit) {
                 v.addElement(node);
             } else if (controller.compare(node, test) > 0) {
                 pastLimit = true;
                 v.addElement(node);
-            } 
+            }
         }
-        return new NodeSetExtent(v, controller);                           
+        return new NodeSetExtent(v, controller);
 
     }
 
@@ -499,7 +499,7 @@ public class Extensions  {
         Not notexp = new Not();
         notexp.addArgument(expression);
         return !(new FilterEnumerator(nsv, notexp, context.newContext(), false)
-                    .hasMoreElements());        
+                    .hasMoreElements());
     }
 
 
@@ -510,7 +510,7 @@ public class Extensions  {
     public static NodeEnumeration range(Context context, double start, double finish) throws XPathException {
         int a = (int)Round.round(start);
         int b = (int)Round.round(finish);
-        
+
         try {
             TinyBuilder builder = new TinyBuilder();
             NamePool pool = context.getController().getNamePool();
@@ -520,21 +520,21 @@ public class Extensions  {
             builder.setNamePool(pool);
             builder.startDocument();
             AttributeCollection emptyAtts = new AttributeCollection(pool);
-            
+
             for (int i=a; i<=b; i++) {
                 builder.startElement(saxonRange, emptyAtts, namespaces, 1);
                 String n = i+"";
                 builder.characters(n.toCharArray(), 0, n.length());
                 builder.endElement(saxonRange);
             }
-        
+
             builder.endDocument();
             DocumentInfo doc = builder.getCurrentDocument();
-            return doc.getEnumeration(Axis.CHILD, AnyNodeTest.getInstance()); 
-            
+            return doc.getEnumeration(Axis.CHILD, AnyNodeTest.getInstance());
+
         } catch (TransformerException err) {
             throw new XPathException(err);
-        }      
+        }
 
     }
 
@@ -553,7 +553,7 @@ public class Extensions  {
             namespaces[0] = pool.getNamespaceCode("saxon", Namespace.SAXON);
             int saxonToken = pool.allocate("saxon", Namespace.SAXON, "token");
             AttributeCollection emptyAtts = new AttributeCollection(pool);
-    
+
             StringTokenizer st = new StringTokenizer(s);
             while (st.hasMoreTokens()) {
                 builder.startElement(saxonToken, emptyAtts, namespaces, 1);
@@ -561,19 +561,19 @@ public class Extensions  {
                 builder.characters(n.toCharArray(), 0, n.length());
                 builder.endElement(saxonToken);
             }
-                    
+
             builder.endDocument();
             DocumentInfo doc = builder.getCurrentDocument();
-            return doc.getEnumeration(Axis.CHILD, AnyNodeTest.getInstance()); 
+            return doc.getEnumeration(Axis.CHILD, AnyNodeTest.getInstance());
         } catch (TransformerException err) {
             throw new XPathException(err);
-        }               
+        }
     }
 
     /**
     * Return a node-set by tokenizing a supplied string. The argument delim is a String, any character
     * in this string is considered to be a delimiter character, and any sequence of delimiter characters
-    * acts as a separator between tokens. 
+    * acts as a separator between tokens.
     */
 
     public static NodeEnumeration tokenize(Context context, String s, String delim) throws XPathException {
@@ -586,7 +586,7 @@ public class Extensions  {
             namespaces[0] = pool.getNamespaceCode("saxon", Namespace.SAXON);
             int saxonToken = pool.allocate("saxon", Namespace.SAXON, "token");
             AttributeCollection emptyAtts = new AttributeCollection(pool);
-    
+
             StringTokenizer st = new StringTokenizer(s, delim);
             while (st.hasMoreTokens()) {
                 builder.startElement(saxonToken, emptyAtts, namespaces, 1);
@@ -594,13 +594,13 @@ public class Extensions  {
                 builder.characters(n.toCharArray(), 0, n.length());
                 builder.endElement(saxonToken);
             }
-                    
+
             builder.endDocument();
             DocumentInfo doc = builder.getCurrentDocument();
-            return doc.getEnumeration(Axis.CHILD, AnyNodeTest.getInstance());   
+            return doc.getEnumeration(Axis.CHILD, AnyNodeTest.getInstance());
         } catch (TransformerException err) {
             throw new XPathException(err);
-        }    
+        }
     }
 
 
@@ -615,22 +615,22 @@ public class Extensions  {
 	/**
 	* Array of names of node types. You can index into this with the numeric node type.
 	*/
-	
+
 	private static final String[] NODE_TYPE_NAMES =
-		{"Node", "Element", "Attribute", "Text", "?", "?", "?", 
+		{"Node", "Element", "Attribute", "Text", "?", "?", "?",
 			"Processing Instruction", "Comment", "Root", "?", "?", "?", "Namespace"};
 
 	/**
 	* A diagnostic function to print the contents of a node-set
 	*/
-	
+
 	public static String showNodeset(Context c, NodeSetValue in) throws XPathException {
-		System.err.println("Node-set contents at line " + c.getStaticContext().getLineNumber() + " [");		
-		NodeEnumeration enum = in.enumerate(c, true);
+		System.err.println("Node-set contents at line " + c.getStaticContext().getLineNumber() + " [");
+		NodeEnumeration enm = in.enumerate(c, true);
 		int count = 0;
-		while (enum.hasMoreElements()) {
+		while (enm.hasMoreElements()) {
 			count++;
-			NodeInfo next = enum.nextElement();
+			NodeInfo next = enm.nextElement();
 			String typeName = NODE_TYPE_NAMES[next.getNodeType()];
 			System.err.println("  " + typeName + " " +
 								 next.getDisplayName() + " " +
@@ -640,7 +640,7 @@ public class Extensions  {
 		System.err.println("] (Total number of nodes: " + count + ")");
 		return "";
 	}
-								 
+
 
     /**
     * Test whether an encapsulated Java object is null
@@ -652,7 +652,7 @@ public class Extensions  {
 
 
     /**
-    * Save a value associated with the context node 
+    * Save a value associated with the context node
     */
 
     public static void setUserData(Context c, String name, Value value) throws XPathException {
@@ -677,17 +677,17 @@ public class Extensions  {
 	/**
 	* Return the Context object
 	*/
-	
+
 	public static Context getContext(Context c) {
 		return c;
 	}
-	
+
 	/**
 	* Get a pseudo-attribute of a processing instruction. Return an empty string
 	* if the context node is not a processing instruction, or if the pseudo-attribute
 	* is not present. Character references and built-in entity references are expanded
 	*/
-	
+
 	public static String getPseudoAttribute(Context c, String name) {
 	    NodeInfo pi = c.getContextNodeInfo();
 	    if (pi.getNodeType() != NodeInfo.PI) return "";
@@ -695,8 +695,8 @@ public class Extensions  {
 	    if (val==null) return "";
 	    return val;
 	}
-	    
-		
+
+
 
 }
 
@@ -707,18 +707,18 @@ public class Extensions  {
 //
 // The contents of this file are subject to the Mozilla Public License Version 1.0 (the "License");
 // you may not use this file except in compliance with the License. You may obtain a copy of the
-// License at http://www.mozilla.org/MPL/ 
+// License at http://www.mozilla.org/MPL/
 //
 // Software distributed under the License is distributed on an "AS IS" basis,
 // WITHOUT WARRANTY OF ANY KIND, either express or implied.
-// See the License for the specific language governing rights and limitations under the License. 
+// See the License for the specific language governing rights and limitations under the License.
 //
-// The Original Code is: all this file. 
+// The Original Code is: all this file.
 //
 // The Initial Developer of the Original Code is
 // Michael Kay of International Computers Limited (mhkay@iclway.co.uk).
 //
-// Portions created by (your name) are Copyright (C) (your legal entity). All Rights Reserved. 
+// Portions created by (your name) are Copyright (C) (your legal entity). All Rights Reserved.
 //
-// Contributor(s): none. 
+// Contributor(s): none.
 //
