@@ -1,23 +1,21 @@
 package com.icl.saxon.output;
-import com.icl.saxon.*;
-import com.icl.saxon.charcode.*;
-import com.icl.saxon.om.Namespace;
-import com.icl.saxon.om.NamePool;
+import com.icl.saxon.charcode.CharacterSet;
+import com.icl.saxon.charcode.CharacterSetFactory;
+import com.icl.saxon.charcode.UnicodeCharacterSet;
 import org.xml.sax.Attributes;
 import org.xml.sax.Locator;
-import java.io.*;
-import java.util.*;
 
-import javax.xml.transform.Result;
 import javax.xml.transform.OutputKeys;
+import javax.xml.transform.Result;
 import javax.xml.transform.TransformerException;
 import javax.xml.transform.stream.StreamResult;
+import java.util.Properties;
 
 /**
   * XMLEmitter is an Emitter that generates XML output
   * to a specified destination.
   */
-  
+
 public class XMLEmitter extends Emitter
 {
     protected CharacterSet characterSet = null;
@@ -26,7 +24,7 @@ public class XMLEmitter extends Emitter
     protected boolean escaping = true;
     protected boolean openStartTag = false;
     protected boolean declarationIsWritten = false;
-    
+
     protected boolean preferHex = false;
 
 	// a little cache...
@@ -38,7 +36,7 @@ public class XMLEmitter extends Emitter
     static boolean[] specialInText;         // lookup table for special characters in text
     static boolean[] specialInAtt;          // lookup table for special characters in attributes
         // create look-up table for ASCII characters that need special treatment
-    
+
     static {
         specialInText = new boolean[128];
         for (int i=0; i<=127; i++) specialInText[i] = false;
@@ -51,25 +49,25 @@ public class XMLEmitter extends Emitter
         for (int i=0; i<=127; i++) specialInAtt[i] = false;
         specialInAtt['\r'] = true;
         specialInAtt['\n'] = true;
-        specialInAtt['\t'] = true;        
+        specialInAtt['\t'] = true;
         specialInAtt['<'] = true;
         specialInAtt['>'] = true;
         specialInAtt['&'] = true;
         specialInAtt['\"'] = true;
     }
-	
+
     /**
     * Set Document Locator. Provided merely to satisfy the interface.
     */
 
     public void setDocumentLocator(Locator locator) {}
-    
+
 
     /**
     * Start of the document. Make the writer and write the XML declaration.
     */
-    
-    public void startDocument () throws TransformerException 
+
+    public void startDocument () throws TransformerException
     {
         if (characterSet==null) characterSet = new UnicodeCharacterSet();
         writeDeclaration();
@@ -98,21 +96,21 @@ public class XMLEmitter extends Emitter
             String encoding = outputProperties.getProperty(OutputKeys.ENCODING);
             if (encoding==null || encoding.equalsIgnoreCase("utf8")) {
                 encoding = "utf-8";
-            } 
-            
+            }
+
             if (!(encoding.equalsIgnoreCase("utf-8"))) {
                 omit = "no";
             }
 
             String standalone = outputProperties.getProperty(OutputKeys.STANDALONE);
-            
+
             if (omit.equals("no")) {
                 writer.write("<?xml version=\"" + version + "\" " +
                               "encoding=\"" + encoding + "\"" +
                               (standalone!=null ? (" standalone=\"" + standalone + "\"") : "") +
                               "?>");
                     // no longer write a newline character: it's wrong if the output is an
-                    // external general parsed entity          
+                    // external general parsed entity
             }
         } catch (java.io.IOException err) {
             throw new TransformerException(err);
@@ -139,13 +137,13 @@ public class XMLEmitter extends Emitter
             }
         } catch (java.io.IOException err) {
             throw new TransformerException(err);
-        }    
+        }
     }
 
     /**
     * End of the document. Close the output stream.
     */
-    
+
     public void endDocument () throws TransformerException
     {
         try {
@@ -158,29 +156,29 @@ public class XMLEmitter extends Emitter
     /**
     * Start of an element. Output the start tag, escaping special characters.
     */
-    
+
     public void startElement (int nameCode, Attributes attributes,
     						  int[] namespaces, int nscount) throws TransformerException
     {
     	String prefix;
     	String uri;
     	String displayName;
-    	
+
     	if (nameCode==lastNameCode) {
     		prefix = lastPrefix;
     		uri = lastURI;
     		displayName = lastDisplayName;
-    	} else {    	
+    	} else {
 	    	prefix = namePool.getPrefix(nameCode);
 	    	uri = namePool.getURI(nameCode);
 	    	displayName = namePool.getDisplayName(nameCode);
-	    	
+
 	    	lastNameCode = nameCode;
     		lastDisplayName = displayName;
     		lastPrefix = prefix;
     		lastURI = uri;
 	    }
-    	       
+
         try {
             if (empty) {
                 String systemId = outputProperties.getProperty(OutputKeys.DOCTYPE_SYSTEM);
@@ -209,12 +207,12 @@ public class XMLEmitter extends Emitter
                 } else {
                     writeAttribute(nameCode, "xmlns:" + nsprefix, "CDATA", nsuri);
                 }
-                
+
             }
 
             // output the attributes
 
-            for (int i=0; i<attributes.getLength(); i++) {  
+            for (int i=0; i<attributes.getLength(); i++) {
                 writer.write(' ');
                 writeAttribute(
                     nameCode,
@@ -223,10 +221,10 @@ public class XMLEmitter extends Emitter
                     attributes.getValue(i));
             }
             openStartTag = true;
-            
+
         } catch (java.io.IOException err) {
             throw new TransformerException(err);
-        }            
+        }
     }
 
     protected void closeStartTag(int nameCode, boolean emptyTag) throws TransformerException {
@@ -251,7 +249,7 @@ public class XMLEmitter extends Emitter
     protected String emptyElementTagCloser(int nameCode) {
         return "/>";
     }
-    
+
     /**
     * Write attribute name=value pair. The element name is not used in this version of the
     * method, but is used in the HTML subclass.
@@ -278,7 +276,7 @@ public class XMLEmitter extends Emitter
                 value.getChars(0, len, attbuff1, 0);
                 writeEscape(attbuff1, 0, len, true);
                 writer.write('\"');
-            }        
+            }
         } catch (java.io.IOException err) {
             throw new TransformerException(err);
         }
@@ -297,7 +295,7 @@ public class XMLEmitter extends Emitter
         }
     }
 
-    protected boolean testCharacters(char[] array, int start, int len) 
+    protected boolean testCharacters(char[] array, int start, int len)
     //throws TransformerException
     {
         for (int i=start; i<len; i++) {
@@ -339,7 +337,7 @@ public class XMLEmitter extends Emitter
     */
 
     public void characters (char[] ch, int start, int length) throws TransformerException
-    {   
+    {
         try {
             if (openStartTag) {
                 closeStartTag(-1, false);
@@ -363,7 +361,7 @@ public class XMLEmitter extends Emitter
     /**
     * Handle a processing instruction.
     */
-    
+
     public void processingInstruction (String target, String data)
         throws TransformerException
     {
@@ -383,14 +381,14 @@ public class XMLEmitter extends Emitter
     * @param start The start position of the input string within the character array
     * @param length The length of the input string within the character array
     * This method converts the XML special characters (such as < and &) into their
-    * predefined entities. 
+    * predefined entities.
     */
 
     protected void writeEscape(char ch[], int start, int length, boolean inAttribute)
     throws java.io.IOException {
         int segstart = start;
         boolean[] specialChars = (inAttribute ? specialInAtt : specialInText);
-        
+
         while (segstart < start+length) {
             int i = segstart;
 
@@ -409,7 +407,7 @@ public class XMLEmitter extends Emitter
             if (ch[i]>127) {
 
                 // process characters not available in the current encoding
-                
+
                 int charval;
 
                 //test for surrogate pairs
@@ -470,8 +468,8 @@ public class XMLEmitter extends Emitter
 	            charref[o++]=code.charAt(k);
 	        }
 	        charref[o++]=';';
-	        writer.write(charref, 0, o);			
-		} else {        
+	        writer.write(charref, 0, o);
+		} else {
 	        int o = 0;
 	        charref[o++]='&';
 	        charref[o++]='#';
@@ -496,7 +494,7 @@ public class XMLEmitter extends Emitter
     /**
     * Handle a comment.
     */
-    
+
     public void comment (char ch[], int start, int length) throws TransformerException
     {
         try {
@@ -529,37 +527,37 @@ public class XMLEmitter extends Emitter
     /**
     * Set output properties
     */
-    
+
     public void setOutputProperties(Properties details) {
         characterSet = CharacterSetFactory.getCharacterSet(details);
         super.setOutputProperties(details);
     }
-    
+
     /**
     * Set the URI for an unparsed entity in the document.
     */
 
     public void setUnparsedEntity(String name, String uri) throws TransformerException {
 	}
-	
+
 
 }
 
 //
 // The contents of this file are subject to the Mozilla Public License Version 1.0 (the "License");
 // you may not use this file except in compliance with the License. You may obtain a copy of the
-// License at http://www.mozilla.org/MPL/ 
+// License at http://www.mozilla.org/MPL/
 //
 // Software distributed under the License is distributed on an "AS IS" basis,
 // WITHOUT WARRANTY OF ANY KIND, either express or implied.
-// See the License for the specific language governing rights and limitations under the License. 
+// See the License for the specific language governing rights and limitations under the License.
 //
-// The Original Code is: all this file. 
+// The Original Code is: all this file.
 //
 // The Initial Developer of the Original Code is
 // Michael Kay of International Computers Limited (mhkay@iclway.co.uk).
 //
-// Portions created by (your name) are Copyright (C) (your legal entity). All Rights Reserved. 
+// Portions created by (your name) are Copyright (C) (your legal entity). All Rights Reserved.
 //
-// Contributor(s): none. 
+// Contributor(s): none.
 //
