@@ -1,30 +1,25 @@
 package com.icl.saxon.tinytree;
-import com.icl.saxon.om.*;
-import com.icl.saxon.om.Axis;
-import com.icl.saxon.Controller;
-import com.icl.saxon.Context;
-import com.icl.saxon.PreparedStyleSheet;
-import com.icl.saxon.PIGrabber;
 import com.icl.saxon.KeyManager;
 import com.icl.saxon.expr.NodeSetExtent;
-import com.icl.saxon.expr.XPathException;
+import com.icl.saxon.om.*;
 import com.icl.saxon.output.Outputter;
-import com.icl.saxon.sort.LocalOrderComparer;
-import com.icl.saxon.pattern.Pattern;
 import com.icl.saxon.pattern.AnyNodeTest;
+import com.icl.saxon.sort.LocalOrderComparer;
 import com.icl.saxon.tree.LineNumberMap;
 import com.icl.saxon.tree.SystemIdMap;
-import java.util.Hashtable;
-import java.net.URL;
+import org.w3c.dom.DOMConfiguration;
+import org.w3c.dom.DOMException;
+import org.w3c.dom.Document;
+import org.w3c.dom.Node;
 
-import org.w3c.dom.*;
 import javax.xml.transform.TransformerException;
+import java.util.Hashtable;
 
 
 /**
   * A node in the XML parse tree representing the Document itself (or equivalently, the root
   * node of the Document).<P>
-  * @author <A HREF="mailto:mhkay@iclway.co.uk>Michael H. Kay</A> 
+  * @author Michael H. Kay
   * @version 26 April 1999
   */
 
@@ -63,7 +58,7 @@ public final class TinyDocumentImpl extends TinyParentNodeImpl
     protected int numberOfNamespaces = 0;
     protected int[] namespaceParent = new int[20];
     protected int[] namespaceCode = new int[20];
-    
+
     private LineNumberMap lineNumberMap;
     private SystemIdMap systemIdMap = new SystemIdMap();
 
@@ -82,16 +77,16 @@ public final class TinyDocumentImpl extends TinyParentNodeImpl
 	/**
 	* Set the name pool used for all names in this document
 	*/
-	
+
 	public void setNamePool(NamePool pool) {
 		namePool = pool;
 		addNamespace(0, pool.getNamespaceCode("xml", Namespace.XML));
 	}
-	
+
 	/**
 	* Get the name pool used for the names in this document
 	*/
-	
+
 	public NamePool getNamePool() {
 		return namePool;
 	}
@@ -170,10 +165,10 @@ public final class TinyDocumentImpl extends TinyParentNodeImpl
         /*NEXT*/ next[numberOfNodes] = -1;      // safety precaution, esp for preview mode
 
         if (depth0 == 1) lastLevelOneNode = numberOfNodes;
-        
+
         numberOfNodes++;
     }
-    
+
     protected void appendChars(char[] chars, int start, int length) {
         while (charBuffer.length < charBufferLength + length) {
             char[] ch2 = new char[charBuffer.length * 2];
@@ -182,15 +177,15 @@ public final class TinyDocumentImpl extends TinyParentNodeImpl
         }
         System.arraycopy(chars, start, charBuffer, charBufferLength, length);
         charBufferLength += length;
-    } 
-    
+    }
+
     /**
     * Truncate the tree: used in preview mode to delete an element after it has
     * been processed
     */
-    
+
     protected void truncate(int nodes) {
-        
+
         if (nodes==numberOfNodes) return;
 
         // shrink the text buffer
@@ -200,14 +195,14 @@ public final class TinyDocumentImpl extends TinyParentNodeImpl
                 break;
             }
         }
-        
+
         // shrink the attributes array
         for (int i=nodes; i<numberOfNodes; i++) {
             if (nodeType[i]==NodeInfo.ELEMENT && offset[i]>=0) {
                 numberOfAttributes = offset[i];
                 break;
             }
-        }        
+        }
 
         // shrink the namespace array
         for (int i=nodes; i<numberOfNodes; i++) {
@@ -216,18 +211,18 @@ public final class TinyDocumentImpl extends TinyParentNodeImpl
                 break;
             }
         }
-        
-        // TODO: shrink the comment buffer        
 
-        // shrink the main node array                                 
+        // TODO: shrink the comment buffer
+
+        // shrink the main node array
         numberOfNodes = nodes;
-        
+
         // kill the prior index, to be rebuilt when needed
         prior = null;
-        
+
         // add a dummy node at the end, because some axes such as "following"
         // can otherwise walk off the end
-        
+
         nodeType[nodes] = (byte)NodeInfo.ROOT;
         depth[nodes] = 0;
         // System.err.println("After truncate:"); diagnosticDump();
@@ -236,13 +231,13 @@ public final class TinyDocumentImpl extends TinyParentNodeImpl
     /**
     * On demand, make an index for quick access to preceding-sibling nodes
     */
-    
+
     protected void ensurePriorIndex() {
         if (prior==null) {
             makePriorIndex();
         }
     }
-    
+
     private synchronized void makePriorIndex() {
         prior = new int[numberOfNodes];
         for (int i=0; i<numberOfNodes; i++) {
@@ -255,7 +250,7 @@ public final class TinyDocumentImpl extends TinyParentNodeImpl
             }
         }
     }
- 
+
 
     protected void addAttribute(int parent0, int code0, String type0, String value0) {
         ensureAttributeCapacity();
@@ -263,7 +258,7 @@ public final class TinyDocumentImpl extends TinyParentNodeImpl
         attCode[numberOfAttributes] = code0;
         attValue[numberOfAttributes] = value0;
         numberOfAttributes++;
-        
+
         if (type0.equals("ID")) {
         	if (idTable==null) {
         		idTable = new Hashtable();
@@ -299,7 +294,7 @@ public final class TinyDocumentImpl extends TinyParentNodeImpl
 
     /**
     * Get the node sequence number (in document order). Sequence numbers are monotonic but not
-    * consecutive. 
+    * consecutive.
     */
 
     public long getSequenceNumber() {
@@ -343,7 +338,7 @@ public final class TinyDocumentImpl extends TinyParentNodeImpl
         }
         systemIdMap.setSystemId(nodeNr, uri);
     }
-        
+
     /**
     * Get the system id of this root node
     */
@@ -374,7 +369,7 @@ public final class TinyDocumentImpl extends TinyParentNodeImpl
         }
         systemIdMap.setSystemId(seq, uri);
     }
-        
+
 
     /**
     * Get the system id of an element in the document
@@ -441,7 +436,7 @@ public final class TinyDocumentImpl extends TinyParentNodeImpl
     public NodeInfo getParent()  {
         return null;
     }
-    
+
     /**
     * Get the root (document) node
     * @return the DocumentInfo representing this document
@@ -453,7 +448,7 @@ public final class TinyDocumentImpl extends TinyParentNodeImpl
 
     /**
     * Get a character string that uniquely identifies this node within the document
-    * @return the empty string 
+    * @return the empty string
     */
 
     public String generateId() {
@@ -493,7 +488,7 @@ public final class TinyDocumentImpl extends TinyParentNodeImpl
         }
         return (AxisEnumeration)list.enumerate();
     }
-                    
+
     /**
     * Register a unique element ID. Fails if there is already an element with that ID.
     * @param e The NodeInfo (always an element) having a particular unique ID value
@@ -506,7 +501,7 @@ public final class TinyDocumentImpl extends TinyParentNodeImpl
         if (old==null) {
             idTable.put(id, e);
         }
-        
+
     }
 
     /**
@@ -524,7 +519,7 @@ public final class TinyDocumentImpl extends TinyParentNodeImpl
     /**
     * Get the index for a given key
     * @param keymanager The key manager managing this key
-    * @int fingerprint The fingerprint of the name of the key (unique with the key manager)
+    * @param fingerprint The fingerprint of the name of the key (unique with the key manager)
     * @return The index, if one has been built, in the form of a Hashtable that
     * maps the key value to a set of nodes having that key value. If no index
     * has been built, returns null.
@@ -607,10 +602,10 @@ public final class TinyDocumentImpl extends TinyParentNodeImpl
         // a stack, so that end tags could be written when the depth decreases.
 
         // output the children
-        
-        AxisEnumeration children = 
+
+        AxisEnumeration children =
             getEnumeration(Axis.CHILD, AnyNodeTest.getInstance());
-                    
+
         while (children.hasMoreElements()) {
             children.nextElement().copy(out);
         }
@@ -619,7 +614,7 @@ public final class TinyDocumentImpl extends TinyParentNodeImpl
 	/**
 	* Produce diagnostic print of main tree arrays
 	*/
-	
+
 	public void diagnosticDump() {
 		System.err.println("Node\ttype\tdepth\toffset\tlength");
 		for (int i=0; i<numberOfNodes; i++) {
@@ -627,24 +622,259 @@ public final class TinyDocumentImpl extends TinyParentNodeImpl
 									 offset[i] + "\t" + length[i] + "\t" + Navigator.getPath(getNode(i)));
 		}
 	}
-    
+
+    /**
+       * Attempts to adopt a node from another document to this document.
+       * @param source The node to move into this document.
+       * @return The adopted node, or <code>null</code> if this operation
+       *         fails, such as when the source node comes from a different
+       *         implementation.
+       * @throws org.w3c.dom.DOMException NOT_SUPPORTED_ERR: Raised if the source node is of type
+       *                                  <code>DOCUMENT</code>, <code>DOCUMENT_TYPE</code>.
+       *                                  <br>NO_MODIFICATION_ALLOWED_ERR: Raised when the source node is
+       *                                  readonly.
+       * @since DOM Level 3
+       */
+      public Node adoptNode(Node source) throws DOMException {
+          disallowUpdate();
+          return null;
+      }
+
+      /**
+       * The location of the document or <code>null</code> if undefined or if
+       * the <code>Document</code> was created using
+       * <code>DOMImplementation.createDocument</code>. No lexical checking is
+       * performed when setting this attribute; this could result in a
+       * <code>null</code> value returned when using <code>Node.baseURI</code>
+       * .
+       * <br> Beware that when the <code>Document</code> supports the feature
+       * "HTML" [<a href='http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109'>DOM Level 2 HTML</a>]
+       * , the href attribute of the HTML BASE element takes precedence over
+       * this attribute when computing <code>Node.baseURI</code>.
+       *
+       * @since DOM Level 3
+       */
+      public String getDocumentURI() {
+          return getSystemId();
+      }
+
+      /**
+       * The configuration used when <code>Document.normalizeDocument()</code>
+       * is invoked.
+       *
+       * @since DOM Level 3
+       */
+      public DOMConfiguration getDomConfig() {
+          return null;
+      }
+
+      /**
+       * An attribute specifying the encoding used for this document at the time
+       * of the parsing. This is <code>null</code> when it is not known, such
+       * as when the <code>Document</code> was created in memory.
+       *
+       * @since DOM Level 3
+       */
+      public String getInputEncoding() {
+          return null;
+      }
+
+      /**
+       * An attribute specifying whether error checking is enforced or not. When
+       * set to <code>false</code>, the implementation is free to not test
+       * every possible error case normally defined on DOM operations, and not
+       * raise any <code>DOMException</code> on DOM operations or report
+       * errors while using <code>Document.normalizeDocument()</code>. In case
+       * of error, the behavior is undefined. This attribute is
+       * <code>true</code> by default.
+       *
+       * @since DOM Level 3
+       */
+      public boolean getStrictErrorChecking() {
+          return true;
+      }
+
+      /**
+       * An attribute specifying, as part of the <a href='http://www.w3.org/TR/2004/REC-xml-20040204#NT-XMLDecl'>XML declaration</a>, the encoding of this document. This is <code>null</code> when
+       * unspecified or when it is not known, such as when the
+       * <code>Document</code> was created in memory.
+       *
+       * @since DOM Level 3
+       */
+      public String getXmlEncoding() {
+          return null;
+      }
+
+      /**
+       * An attribute specifying, as part of the <a href='http://www.w3.org/TR/2004/REC-xml-20040204#NT-XMLDecl'>XML declaration</a>, whether this document is standalone. This is <code>false</code> when
+       * unspecified.
+       * <p ><b>Note:</b>  No verification is done on the value when setting
+       * this attribute. Applications should use
+       * <code>Document.normalizeDocument()</code> with the "validate"
+       * parameter to verify if the value matches the <a href='http://www.w3.org/TR/2004/REC-xml-20040204#sec-rmd'>validity
+       * constraint for standalone document declaration</a> as defined in [<a href='http://www.w3.org/TR/2004/REC-xml-20040204'>XML 1.0</a>].
+       *
+       * @since DOM Level 3
+       */
+      public boolean getXmlStandalone() {
+          return false;
+      }
+
+      /**
+       * An attribute specifying, as part of the <a href='http://www.w3.org/TR/2004/REC-xml-20040204#NT-XMLDecl'>XML declaration</a>, the version number of this document. If there is no declaration and if
+       * this document supports the "XML" feature, the value is
+       * <code>"1.0"</code>.
+       *
+       * @since DOM Level 3
+       */
+      public String getXmlVersion() {
+          return "1.0";
+      }
+
+      /**
+       * This method acts as if the document was going through a save and load
+       * cycle, putting the document in a "normal" form.
+       * @since DOM Level 3
+       */
+      public void normalizeDocument() {
+          disallowUpdate();
+      }
+
+      /**
+       * Rename an existing node of type <code>ELEMENT_NODE</code> or
+       * <code>ATTRIBUTE_NODE</code>.
+
+       *
+       * @param n             The node to rename.
+       * @param namespaceURI  The new namespace URI.
+       * @param qualifiedName The new qualified name.
+       * @return The renamed node. This is either the specified node or the new
+       *         node that was created to replace the specified node.
+       * @throws org.w3c.dom.DOMException NOT_SUPPORTED_ERR: Raised when the type of the specified node is
+       *                                  neither <code>ELEMENT_NODE</code> nor <code>ATTRIBUTE_NODE</code>,
+       *                                  or if the implementation does not support the renaming of the
+       *                                  document element.
+       *                                  <br>INVALID_CHARACTER_ERR: Raised if the new qualified name is not an
+       *                                  XML name according to the XML version in use specified in the
+       *                                  <code>Document.xmlVersion</code> attribute.
+       *                                  <br>WRONG_DOCUMENT_ERR: Raised when the specified node was created
+       *                                  from a different document than this document.
+       *                                  <br>NAMESPACE_ERR: Raised if the <code>qualifiedName</code> is a
+       *                                  malformed qualified name, if the <code>qualifiedName</code> has a
+       *                                  prefix and the <code>namespaceURI</code> is <code>null</code>, or
+       *                                  if the <code>qualifiedName</code> has a prefix that is "xml" and
+       *                                  the <code>namespaceURI</code> is different from "<a href='http://www.w3.org/XML/1998/namespace'>
+       *                                  http://www.w3.org/XML/1998/namespace</a>" [<a href='http://www.w3.org/TR/1999/REC-xml-names-19990114/'>XML Namespaces</a>]
+       *                                  . Also raised, when the node being renamed is an attribute, if the
+       *                                  <code>qualifiedName</code>, or its prefix, is "xmlns" and the
+       *                                  <code>namespaceURI</code> is different from "<a href='http://www.w3.org/2000/xmlns/'>http://www.w3.org/2000/xmlns/</a>".
+       * @since DOM Level 3
+       */
+      public Node renameNode(Node n, String namespaceURI, String qualifiedName) throws DOMException {
+          disallowUpdate();
+          return null;
+      }
+
+      /**
+       * The location of the document or <code>null</code> if undefined or if
+       * the <code>Document</code> was created using
+       * <code>DOMImplementation.createDocument</code>. No lexical checking is
+       * performed when setting this attribute; this could result in a
+       * <code>null</code> value returned when using <code>Node.baseURI</code>
+       * .
+       * <br> Beware that when the <code>Document</code> supports the feature
+       * "HTML" [<a href='http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109'>DOM Level 2 HTML</a>]
+       * , the href attribute of the HTML BASE element takes precedence over
+       * this attribute when computing <code>Node.baseURI</code>.
+       *
+       * @since DOM Level 3
+       */
+      public void setDocumentURI(String documentURI) {
+          setSystemId(documentURI);
+      }
+
+      /**
+       * An attribute specifying whether error checking is enforced or not. When
+       * set to <code>false</code>, the implementation is free to not test
+       * every possible error case normally defined on DOM operations, and not
+       * raise any <code>DOMException</code> on DOM operations or report
+       * errors while using <code>Document.normalizeDocument()</code>. In case
+       * of error, the behavior is undefined. This attribute is
+       * <code>true</code> by default.
+       *
+       * @since DOM Level 3
+       */
+      public void setStrictErrorChecking(boolean strictErrorChecking) {
+          throw new UnsupportedOperationException("setStrictErrorChecking() is not supported");
+      }
+
+      /**
+       * An attribute specifying, as part of the <a href='http://www.w3.org/TR/2004/REC-xml-20040204#NT-XMLDecl'>XML declaration</a>, whether this document is standalone. This is <code>false</code> when
+       * unspecified.
+       * <p ><b>Note:</b>  No verification is done on the value when setting
+       * this attribute. Applications should use
+       * <code>Document.normalizeDocument()</code> with the "validate"
+       * parameter to verify if the value matches the <a href='http://www.w3.org/TR/2004/REC-xml-20040204#sec-rmd'>validity
+       * constraint for standalone document declaration</a> as defined in [<a href='http://www.w3.org/TR/2004/REC-xml-20040204'>XML 1.0</a>].
+       *
+       * @throws org.w3c.dom.DOMException NOT_SUPPORTED_ERR: Raised if this document does not support the
+       *                                  "XML" feature.
+       * @since DOM Level 3
+       */
+      public void setXmlStandalone(boolean xmlStandalone) throws DOMException {
+          disallowUpdate();
+      }
+
+      /**
+       * An attribute specifying, as part of the <a href='http://www.w3.org/TR/2004/REC-xml-20040204#NT-XMLDecl'>XML declaration</a>, the version number of this document. If there is no declaration and if
+       * this document supports the "XML" feature, the value is
+       * <code>"1.0"</code>. If this document does not support the "XML"
+       * feature, the value is always <code>null</code>. Changing this
+       * attribute will affect methods that check for invalid characters in
+       * XML names. Application should invoke
+       * <code>Document.normalizeDocument()</code> in order to check for
+       * invalid characters in the <code>Node</code>s that are already part of
+       * this <code>Document</code>.
+       * <br> DOM applications may use the
+       * <code>DOMImplementation.hasFeature(feature, version)</code> method
+       * with parameter values "XMLVersion" and "1.0" (respectively) to
+       * determine if an implementation supports [<a href='http://www.w3.org/TR/2004/REC-xml-20040204'>XML 1.0</a>]. DOM
+       * applications may use the same method with parameter values
+       * "XMLVersion" and "1.1" (respectively) to determine if an
+       * implementation supports [<a href='http://www.w3.org/TR/2004/REC-xml11-20040204/'>XML 1.1</a>]. In both
+       * cases, in order to support XML, an implementation must also support
+       * the "XML" feature defined in this specification. <code>Document</code>
+       * objects supporting a version of the "XMLVersion" feature must not
+       * raise a <code>NOT_SUPPORTED_ERR</code> exception for the same version
+       * number when using <code>Document.xmlVersion</code>.
+       *
+       * @throws org.w3c.dom.DOMException NOT_SUPPORTED_ERR: Raised if the version is set to a value that is
+       *                                  not supported by this <code>Document</code> or if this document
+       *                                  does not support the "XML" feature.
+       * @since DOM Level 3
+       */
+      public void setXmlVersion(String xmlVersion) throws DOMException {
+          disallowUpdate();
+      }
+
+
 }
 
 //
 // The contents of this file are subject to the Mozilla Public License Version 1.0 (the "License");
 // you may not use this file except in compliance with the License. You may obtain a copy of the
-// License at http://www.mozilla.org/MPL/ 
+// License at http://www.mozilla.org/MPL/
 //
 // Software distributed under the License is distributed on an "AS IS" basis,
 // WITHOUT WARRANTY OF ANY KIND, either express or implied.
-// See the License for the specific language governing rights and limitations under the License. 
+// See the License for the specific language governing rights and limitations under the License.
 //
-// The Original Code is: all this file except PB-SYNC section. 
+// The Original Code is: all this file except PB-SYNC section.
 //
 // The Initial Developer of the Original Code is
 // Michael Kay of International Computers Limited (mhkay@iclway.co.uk).
 //
-// Portions marked PB-SYNC are Copyright (C) Peter Bryant (pbryant@bigfoot.com). All Rights Reserved. 
+// Portions marked PB-SYNC are Copyright (C) Peter Bryant (pbryant@bigfoot.com). All Rights Reserved.
 //
-// Contributor(s): Michael Kay, Peter Bryant. 
+// Contributor(s): Michael Kay, Peter Bryant.
 //
